#
# spec file for package parcellite
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           parcellite
Version:        1.2.5
Release:        2.1
Summary:        A lightweight GTK+ clipboard manager
License:        GPL-3.0-or-later
Group:          Productivity/Other
URL:            https://github.com/rickyrockrat/parcellite
Source:         https://github.com/rickyrockrat/parcellite/archive/refs/tags/%{version}.tar.gz
# PATCH-FIX-UPSTREAM marguerite@opensuse.org -- tweak default settings.
Patch0:         parcellite-1.1.7-defaults.patch
Patch1:         parcellite-1.1.9_no_kde_start.patch
Patch2:         parcellite-1.2.4.0-simple.patch
Patch3:         fix-manpage-name.patch
BuildRequires:  gnome-icon-theme
BuildRequires:  intltool >= 0.23
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(gtk+-2.0) >= 2.10.0
# needed for auto-paste
Requires:       xdotool

%description
Parcellite is a stripped down, basic-features-only clipboard manager with a
small memory footprint for those who like simplicity.

In GNOME and Xfce the clipboard manager will be started automatically. For
other desktops or window managers you should also install a panel with a
system tray or notification area if you want to use this package.

%prep
%autosetup -p1

%build
%make_build
sed -i -e '/^Icon/s/=.*/=parcellite/' data/parcellite.desktop

%install
%make_install
mkdir -p %{buildroot}%{_datadir}/pixmaps
install -m 644 \
	%{_datadir}/icons/gnome/32x32/actions/edit-paste.png \
	%{buildroot}%{_datadir}/pixmaps/%{name}.png
%find_lang %{name}
%suse_update_desktop_file -r -G "Clipboard Manager" %{name} GTK GNOME Utility DesktopUtility
%suse_update_desktop_file -r -G "Clipboard Manager" %{name}-startup GTK GNOME Utility DesktopUtility TrayIcon

%post
%desktop_database_post

%postun
%desktop_database_postun

%files -f %{name}.lang
%license COPYING
%doc AUTHORS ChangeLog README NEWS
%config(noreplace) %{_sysconfdir}/xdg/autostart/%{name}-startup.desktop
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/pixmaps/%{name}.*
%{_mandir}/man1/*

%changelog
* Mon Mar 17 2025 Thorsten Kukuk <kukuk@suse.com>
- fix-manpage-name.patch: fix name of installed manual page
* Thu Jul 11 2024 Michael Vetter <mvetter@suse.com>
- Update to 1.2.5:
  * Updated man page for fifo operation
  * Removed autotools. Just use make - see the README
* Fri Jul  5 2024 ming li <mli@suse.com>
- update to 1.2.4:
  * Fixed Segfault on Rocky 9, and potential on any OS.
* Mon May 13 2024 Michael Vetter <mvetter@suse.com>
- Switch to https://github.com/rickyrockrat/parcellite
  by the same person but containing newer tags than sf
- Update to 1.2.2:
  * Added Makefile.simple as a fix before changing autodiscover build system.
  * Fixed issue with systemd logging output.
  * Fixed bug with zero length history file.
  * Added Disable clear history.
  * Added manual Unity setting.
  * Added save_history_Lineno preference for save as option
  * Added fifo command to save history. echo "save_history
    /path/to/file" >/home/user/.local/share/parcellite/fifo_cmd
  * Fixed bug where single and double quotes are lost when using xdotool
    and keyboard input.
- Update to 1.2.3:
  * Added top_builddir definition for some intltools.
  * Added basque translation.
- Update to 1.2.4.0:
  * Fixed span parse error for preferenced dialog.
  * Move icon menu up 150 so it is not over systray, and history to top if not set in pref.
  * Attempt to fix xdotool segfaulting when passed mis-matched quotes. This may break xdotool deps.
  * Added install-bin, install-doc, and install-lang to support Alpine's sparse packages.
- Update parcellite-1.1.7-defaults.patch
- Add parcellite-1.2.4.0-simple.patch to remove non existing header
- Run spec-cleaner
* Thu Feb 29 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN.
* Wed Aug  4 2021 Giacomo Comes <gcomes.obs@gmail.com> - 1.2.1
- fix parcellite-1.1.9_no_kde_start.patch boo#904731, boo#958343
* Fri Nov  3 2017 gutaper@gmail.com
- new upstream version 1.2.1
  * Implemented patch from Christopher Oliver that fixes a memory access bug on history clear.
  * Fixed minor missing fclose bug in save_history credits dcb.
  * Fixed bug 144, Clipboard text quoted for action commands.
- changelog from 1.1.9 to 1.2.0
  * Removed -d option.
  * Fixed bug 151, history clear not working.
  * Fixed bug 150, Command line examples not working. Note: parcellite must be running already.
  * Fixed bug 147, resource leak on history file.
  * Fixed bug 144, Clipboard text quoted for action commands.
  * Fixed bug 143, Parcellite fails to start as daemon. Also fixes Debian bug 785472.
  * Added TW_zh .po file.
* Wed Nov 12 2014 andrea@opensuse.org
- Fixed boo#904731 adding parcellite-1.1.9_no_kde_start.patch
* Thu Oct  2 2014 trcs@gmx.com
- new upstream version 1.1.9
  * Fixed bug 120, position_history broken. We limit x & y with
    screen limit -100.
  * Fixed bug 124, Enter does not select entry.
  * Fixed bug 125, Unsolicited error message about xdotool.
  * Added feature request 57, change systray icon.
  * Updated Spanish translation by jcsl.
  * Updated Chinese translation by wenjie.
  * Fixed Bug 123, right-click edit broken.
  * Fixed unsolicited error message on startup (related to bug 125).
  * Cleaned up many warnings. Note to self: use env CFLAGS=-Wall
    ./configure –prefix=/usr/local
  * Initial attempt at fixing bugs 129/137/133 - unable to copy
    files in file manager & text deselection.
  * Attempt to clean up ‘malformed email address’ for Lintin.
* Tue Aug  5 2014 trcs@gmx.com
- update to version 1.1.8 revision 532 to fix several bugs
  * Fixed bug 120, position_history broken. We limit x & y with
    screen limit -100.
  * Fixed Bug 123, right-click edit broken.
  * Fixed bug 124, Enter does not select entry.
  * Fixed bug 125, Unsolicited error message about xdotool.
  * Fixed bug 130, Edit clipboard and Clear aren't working in
    Parcellite 1.1.8
  * Added feature request 57, change systray icon.
  * Updated Spanish translation by jcsl.
    + it makes parcellite-1.1.7-Spanish-translation-update.patch
    unnecessary ~> removed
  * Updated Chinese translation by wenjie.
  * Cleaned up many warnings.
    + it makes parcellite-1.1.8-rpmlint-errors.patch unnecessary
    ~> removed
* Sun Aug  3 2014 trcs@gmx.com
- new upstream version 1.1.8
  * Fixed bug 107, segfault when action key missing in parcelliterc.
  * Fixed bug 108, red search-as-you-type with super-K key.
  * Fixed bug 109, segfault when action key missing and history key changed.
  * Updated Russian translation.
  * Fix broken case-sensitive search.
  * Fixed bug 111, unlock a mutext not locked.
  * Fixed history editing problem issue where history is updated while editing.
  * Added emphatic statement about xdotool on the auto-paste tooltip.
  * Added pref_mapper that maps prefs to integer values so we don’t have to string compares in main loop.
    Should decrease CPU cycles considerably in the ticker.
  * Added ability to use system-wide XDG config file on first startup.
  * Added dialog popup if auto-paste is checked and xdotool does not exist.
  * Added item_limit (which is the same thing as data_size) which limits per-item size.
  * Fixed synchronization bug when trim whitespace was selected and processed entry was already in history.
  * Fix of bug in write_fifo.
  * Fix item and data size to correct scaling, and change to KB for better granularity.
  * Fix bug 121, context menu stays up after history menu is deactivated.
  * Fix new bug with memory leak by destroying history menu every time, related to bug 121.
  * Fix minor bug where edit shows up on right-click even when user disabled it.
  * Fix bug where right-click-ctrl/shift did not delete history entries.
- added parcellite-1.1.8-rpmlint-errors.patch which works with the current source files
  * removed parcellite-1.1.7-rpmlint-errors.patch
- require xdotool for auto-paste
* Sun Mar 23 2014 trcs@gmx.com
- updated Spanish translation
  * added parcellite-1.1.7-Spanish-translation-update.patch
* Sun Mar 23 2014 trcs@gmx.com
- new upstream version 1.1.7
  * detailed changelog at http://parcellite.sourceforge.net/?p=293
- removed parcellite-1.1.6-defaults.patch
- removed parcellite-1.1.6-rpmlint-errors.patch
- removed patch: parcellite-1.1.6-gio-missing-link.patch, upstream fixed.
- added parcellite-1.1.7-defaults.patch
- added parcellite-1.1.7-rpmlint-errors.patch
* Wed Sep 11 2013 i@marguerite.su
- update version 1.1.6
  * Fixed Bug #99, Broken CLI functionality. Now looks at XDG_SESSION_COOKIE,
    XDG_SEAT, and DISPLAY, introduced by multi-user fix.
  * Fixed bug where if fifo are not found in client mode, parcellite segfaults.
  * Apply patch for typo in German translation, patch #30.
  * Updated parcellite.pot (cd po && make update-po).
  * Changed name of history file from hist.test to history (debug escape).
    To restore the history, Quit Parcellite, then cd to $HOME/.local/share/parcellite
    mv hist.test history
  * Added script to generate parcellite.pot & check in file, and gets run before
    each release from rel.sh.
  * Updated Brazilian Portuguese translation.
- removed patch: parcellite-0.9.1-german.diff, upstream fixed.
- removed patch: parcellite-0.9.1-defaults.patch, upstream code change, not usable.
- added patch: parcellite-1.1.6-defaults.patch, the new default tweaks from the old patch
- removed patch: parcellite-0.9.1-lxde-autostart.patch, upstream fixed.
- removed patch: parcellite-0.9.2-fix-glib-includes.patch, upstream fixed.
- removed patch: parcellite-1.0.2rc5-rpmlint_happy.patch.
- added patch: parcellite-1.0.2rc5-rpmlint_happy.patch
- added patch: parcellite-1.1.6-gio-missing-link.patch
* Wed Dec 19 2012 andrea@opensuse.org
- new upstream version 1.0.2rc5
  * Fixed 100%% CPU bug that occurs with certain clipboard data.
  * Fixed list not staying at the top of the list.
  * Added patch that corrects clipboard losing text data when app closes.
  * Added more man page information.
  * Created new icon ‘parcellite’ and added it to install.
  * Moved newline to after elipsizing (thanks, Christian).
  * Added right-click delete.
  * Added history location
  * Added search as you type.
  * Added Data Size limt.
  * Fixed build so dist-clean does not remove icons.
  * Added wrapper p_strcmp so it builds with Gtk <2.16
  * and many many more
- removed parcellite-0.9.1-ld_fix.diff now in upstream code
- rebased parcellite-0.9.1-defaults.diff to apply
- added parcellite-1.0.2rc5-rpmlint_happy.patch to fix some compiler warnings
* Tue Jan 10 2012 gber@opensuse.org
- added parcellite-0.9.2-fix-glib-includes.patch in order to
  prevent glib/gtypes.h from being included directly
* Thu Dec  1 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Sat Sep 17 2011 suse-tux@gmx.de
- added Patch3 (parcellite-0.9.1-ld_fix.diff) to fix the build for factory
  (this needs a autoreconf in the %%%%build section)
* Mon Mar 14 2011 gber@opensuse.org
- call %%desktop_database_post/un
* Fri May 21 2010 lnussel@suse.de
- turn on using primary by default again
- leave global shortcuts empty by default
* Mon May 10 2010 guido+opensuse.org@berhoerster.name
- fixed invalid RPM Group
- removed incorrect Settings category from desktop file
- use %%%%suse_update_desktop_file
* Mon Apr  5 2010 andrea@opensuse.org
- removed parcellite-0.9.1-defaults.diff (usability issue)
* Sun Jan 10 2010 andrea@opensuse.org
- New Upstream version 0.9.2
- removed gcc patch (no more useful since accepted upstream)
- source code bzipped
- important changes:
  * added several translations
  * Modified action execution code.
  * Removed dependency on pthreads.
  * Clear option clears clipboard and primary contents.
  * Use accessor functions instead direct access (by Javier Jardon).
  * Add missing include statements to silence gcc warnings (by Ludwig Nussel).
  * Clipboard sync cannot be enabled unless both copy and primary are enabled.
  * Empty clipboard and primary recovery no longer overwrites contents of other types.
  * Removes newline characters (’\n’) from the history menu entries (by Daniel Di Marco).
* Fri Dec 11 2009 andrea@opensuse.org
- fixed parcellite-startup.desktop to allow LXDE to use it
* Fri Jul 17 2009 lnussel@suse.de
- change some defaults:
  * monitor primary
  * sync clipboards
  * disable key bindings as they clash with some of mine :-)
* Wed Jul 15 2009 lnussel@suse.de
- inital package version 0.9.1 based on Fedora's
